@@ -352,6 +352,20 @@ struct retro_core_option_v2_definition option_defs_us[] = {
       },
       "disabled"
    },
+   {
+      BEETLE_OPT(display_osd),
+      "Display OSD Messages",
+      NULL,
+      "Display OSD messages generated by the core.",
+      NULL,
+      "osd",
+      {
+         { "enabled",  NULL },
+         { "disabled", NULL },
+         { NULL, NULL },
+      },
+      "enabled"
+   },
 #if defined(HAVE_OPENGL) || defined(HAVE_OPENGLES) || defined(HAVE_VULKAN)
    {
       BEETLE_OPT(display_vram),
@@ -1211,11 +1225,11 @@ struct retro_core_option_v2_definition option_defs_us[] = {
       NULL,
       NULL,
       {
+         { "auto_toggle", "Allow Automatic Toggling" },
          { "force_progressive", "Progressive Rate" },
          { "force_interlaced",  "Force Interlaced Rate" },
-         { "auto_toggle", "Allow Automatic Toggling" },
       },
-      "force_progressive"
+      "auto_toggle"
    },
    {
       BEETLE_OPT(pal_video_timing_override),
@@ -1643,6 +1657,20 @@ struct retro_core_option_v2_definition option_defs_us[] = {
       },
       "287"
    },
+   {
+      BEETLE_OPT(deinterlacer),
+      "Deinterlace Method",
+      NULL,
+      "'Weave' shows both fields on the same frame for full high resolution still image, 'Bob' sacrificies resolution clarity for motion clarity.",
+      NULL,
+      "video",
+      {
+         { "weave",  "Weave" },
+         { "bob",  "Bob" },
+         { NULL, NULL },
+      },
+      "weave"
+   },
 #ifndef EMSCRIPTEN
    {
       BEETLE_OPT(cd_access_method),
